/****************************************************
 THIS COMMAND FILE GIVES AN OVERVIEW OF SAS 
 DATA MANAGEMENT TASKS

 FILENAME: OVERVIEW.SAS
 ****************************************************/
OPTIONS FORMCHAR="|----|+|---+=|-/\<>*";

options nodate;
title;

data pulse;
   infile "pulse.dat" missover;
   input pulse1 pulse2 ran smokes sex height weight activity;
run;

/*MAKE A COPY OF A SAS DATA SET*/

data newpulse;
   set pulse;
run;

/*Making a Copy of a Permanent SAS Data Set*/

libname sasdata2 v9 "c:\temp\sasdata2";
data sasdata2.pulse;
   infile "pulse.dat" missover;
   input pulse1 pulse2 ran smokes sex height weight activity;
run;

data sasdata2.newpulse;
   set sasdata2.pulse;
run;


/*Creating subsets of data*/

data females;
   set pulse;
   if sex = 2;
run;

data males;
   set pulse;
   if sex = 1;
run;


/*Create two datasets with one data step*/

data males females;
   set pulse;
    if sex = 1 then output males;
    if sex = 2 then output females;
run;


/*DELETE CASES FROM A DATA SET*/

data fixpulse;
   set pulse;
   if pulse1 > 95 then delete;
run;

/*Using Keep and Drop to control the variables in a data set*/

data sbp;
 input id drug sbp1 sbp2 wt sideffct;
 cards;
131 1 154 129 150 1
135 2 149 118 154 1
136 1 137 119 152 0
137 1 142 116 151 1
138 1 156 111 153 0
139 2 163 109 148 1
105 2 141 145 188 0
106 1 139 147 185 1
107 2 170 133 184 0
108 2 148 129 185 0
;

title "Printout of SBP Data Set";
proc print data=sbp;
run;

 /*KEEP STATEMENT*/
data sbp2;
  set sbp;
  sbpchg = sbp2-sbp1;
  keep id drug sbp1 sbp2 sbpchg;
run;

title "Printout of SBP2 Data";
proc print data=sbp2;
run;

 /*DROP STATEMENT*/

data sbp3;
  set sbp;
  drop wt sideffct;
run;

proc print data=sbp3;
   title "Printout of SBP3 Data";
run;

/*KEEP= DATA SET OPTION*/
/*USING KEEP= ON THE INPUT DATA SET*/
data sbp4;
   set sbp(keep=id drug sbp1 sbp2);
   avgsbp = mean(sbp1,sbp2);
run;
proc print data=sbp4;
  title "Printout of SBP4 Data";
run;

/*USING KEEP= ON THE OUTPUT DATA SET*/
data sbp5(keep=id drug avgsbp);
  set sbp;
  avgsbp = mean(sbp1,sbp2);
run;
proc print data=sbp5 (obs=5);
  title "Printout of SBP5 Data";
run;




